Change Log
============

v0.4.0 - released: XXXXX
----------------------------
* Moved to using BootStrap for design
* https://github.com/DigitalCampus/django-oppia/issues/119 - using gravatars now optional




Previous Versions
------------------

.. toctree::
   :maxdepth: 2
   
   changelog_v0.3
   changelog_v0.2
   changelog_v0.1
